Collection Mapping
==================

This is an in-depth discussion of collection mechanics.  For simple examples, see :ref:`alternate_collection_implementations`.

.. automodule:: sqlalchemy.orm.collections

.. autofunction:: attribute_mapped_collection

.. autoclass:: collection

.. autofunction:: collection_adapter

.. autofunction:: column_mapped_collection

.. autofunction:: mapped_collection

